@@ -167,7 +167,9 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
             asset_id=asset_id,
             start=start_timestamp - max_lookback_seconds,
             end=end_timestamp,
-            limit=constants.get('global.query-limit'))
+            limit=constants.get('global.query-limit'),
+            fields=constants.get('global.wits_query_fields', None)
+        )
 
         return scheduler_event
 
@@ -202,7 +204,8 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
                 asset_id=asset_id,
                 start=first_timestamp - max_lookback_seconds,
                 end=end_timestamp,
-                limit=constants.get('global.query-limit')
+                limit=constants.get('global.query-limit'),
+                fields=constants.get('global.wits_query_fields', None)
             )
 
             records = previous_events + records
