@@ -79,15 +79,15 @@ class ActivityModule(Module):
         drillstring_id = first_wits.get('metadata', {}).get('drillstring', None)
         casing_id = first_wits.get('metadata', {}).get('casing', None)
 
-        if not drillstring_id and not casing_id:
-            return []
-
         if drillstring_id:
             active_string_type = 'drillstring'
             active_string_id = drillstring_id
         elif casing_id:
             active_string_type = 'casing'
             active_string_id = casing_id
+        else:
+            active_string_type = None
+            active_string_id = None
 
         if previous_string == active_string_id:
             return []
